﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Editors;

namespace WpfApplication2
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();
			this.DataContext = new ViewModel()
				{
					Data = ChartData.GenerateData(4),
					ComboData = new ObservableCollection<ComboItem>() 
					{
						new ComboItem(){ ID = 0, IsEnabled = true},	
						new ComboItem(){ ID = 1, IsEnabled = true},
						new ComboItem(){ ID = 2, IsEnabled = true},
						new ComboItem(){ ID = 3, IsEnabled = true},
					}
				};
		}
		
		void EditModeEnded(object sender, Infragistics.Windows.Editors.Events.EditModeEndedEventArgs e)
		{
			((sender as XamComboEditor).SelectedItem as ComboItem).IsEnabled = false;
		}

		private void XamDataGrid_CellActivated(object sender, Infragistics.Windows.DataPresenter.Events.CellActivatedEventArgs e)
		{
			Dispatcher.BeginInvoke(new Action(() =>
			{
				if (e.Cell.Field.Name == "ID")
				{
					(CellValuePresenter.FromCell(e.Cell).Editor as XamComboEditor).IsDropDownOpen = true;
					(CellValuePresenter.FromCell(e.Cell).Editor as XamComboEditor).IsDropDownOpen = false;
				}
			}), System.Windows.Threading.DispatcherPriority.Background, null);
			
		}
	}

	public class ViewModel
	{
		public ObservableCollection<ChartData> Data { get; set; }
		public ObservableCollection<ComboItem> ComboData { get; set; }
	}

	public class ChartData
	{
		public int ID { get; set; }
		public double Value1 { get; set; }
		public double Value2 { get; set; }
		public double Value3 { get; set; }

		public static ObservableCollection<ChartData> GenerateData(int count)
		{
			ObservableCollection<ChartData> data = new ObservableCollection<ChartData>();

			Random r = new Random();

			ChartData data0 = new ChartData
			{
				ID = 0,
				Value1 = r.Next(20, 40),
				Value2 = r.Next(20, 40),
				Value3 = r.Next(20, 40),
			};

			data.Add(data0);

			for (int i = 1; i < count; i++)
			{
				ChartData dat = new ChartData
				{
					ID = i,
				};

				if (r.NextDouble() > .5)
				{
					dat.Value1 = data[i - 1].Value1 + r.NextDouble();
					dat.Value2 = data[i - 1].Value2 + r.NextDouble();
					dat.Value3 = data[i - 1].Value3 + r.NextDouble();
				}
				else
				{
					dat.Value1 = data[i - 1].Value1 - r.NextDouble();
					dat.Value2 = data[i - 1].Value2 - r.NextDouble();
					dat.Value3 = data[i - 1].Value3 - r.NextDouble();
				}

				data.Add(dat);
			}

			return data;
		}
	}

	public class ComboItem : INotifyPropertyChanged
	{
		public int ID { get; set; }
		private bool isEnabled;

		public bool IsEnabled
		{
			get { return isEnabled; }
			set 
			{ 
				isEnabled = value;
				PropChanged("IsEnabled");
			}
		}
		

		public event PropertyChangedEventHandler PropertyChanged;

		public void PropChanged(string name)
		{
			if (PropertyChanged != null)
				PropertyChanged(this, new PropertyChangedEventArgs(name));
		}
	}
}
